==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/CssVisibilityPropertyAccessor.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { UIElementPropertyAccessor } from "./UIElementPropertyAccessor";
import { enumGetBox, EnumUtil, markType } from "./type";
import { Visibility_$type } from "./Visibility";
/**
 * @hidden
 */
var CssVisibilityPropertyAccessor = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CssVisibilityPropertyAccessor, _super);
    function CssVisibilityPropertyAccessor() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CssVisibilityPropertyAccessor.prototype.b = function (a) {
        var b = a;
        var c = b.getStyleProperty("visibility");
        if (c != null) {
            switch (c.toLowerCase()) {
                case "collapse":
                case "hidden": return enumGetBox(Visibility_$type, 1);
            }
        }
        return enumGetBox(Visibility_$type, 0);
    };
    CssVisibilityPropertyAccessor.prototype.c = function (a, b) {
        var c = a;
        c.setStyleProperty("visibility", EnumUtil.getEnumValue(Visibility_$type, b) == 1 ? "collapse" : "visible");
    };
    CssVisibilityPropertyAccessor.$t = markType(CssVisibilityPropertyAccessor, 'CssVisibilityPropertyAccessor', UIElementPropertyAccessor.$);
    return CssVisibilityPropertyAccessor;
}(UIElementPropertyAccessor));
export { CssVisibilityPropertyAccessor };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/CssVisibilityPropertyAccessor.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { UIElementPropertyAccessor } from "./UIElementPropertyAccessor";
import { enumGetBox, EnumUtil, markType } from "./type";
import { Visibility_$type } from "./Visibility";
/**
 * @hidden
 */
var CssVisibilityPropertyAccessor = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CssVisibilityPropertyAccessor, _super);
    function CssVisibilityPropertyAccessor() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CssVisibilityPropertyAccessor.prototype.b = function (a) {
        var b = a;
        if (b.getStyleProperty("display") == "none") {
            return enumGetBox(Visibility_$type, 1);
        }
        return enumGetBox(Visibility_$type, 0);
    };
    CssVisibilityPropertyAccessor.prototype.c = function (a, b) {
        var c = a;
        if (EnumUtil.getEnumValue(Visibility_$type, b) == 1) {
            c.hide();
        }
        else {
            c.show();
        }
    };
    CssVisibilityPropertyAccessor.$t = markType(CssVisibilityPropertyAccessor, 'CssVisibilityPropertyAccessor', UIElementPropertyAccessor.$);
    return CssVisibilityPropertyAccessor;
}(UIElementPropertyAccessor));
export { CssVisibilityPropertyAccessor };
